@@ -76,8 +76,7 @@ static int level;		/* brace level */
  * yacc: read yacc file and pickup tag entries.
  */
 void
-yacc(file)
-	const char *file;
+yacc(const char *file)
 {
 	C_family(file, TYPE_YACC);
 }
@@ -85,8 +84,7 @@ yacc(file)
  * C: read C file and pickup tag entries.
  */
 void
-C(file)
-	const char *file;
+C(const char *file)
 {
 	C_family(file, TYPE_C);
 }
@@ -95,9 +93,7 @@ C(file)
  *	i)	type	TYPE_C, TYPE_YACC, TYPE_LEX
  */
 static void
-C_family(file, type)
-	const char *file;
-	int type;
+C_family(const char *file, int type)
 {
 	int c, cc;
 	int savelevel;
@@ -499,8 +495,7 @@ C_family(file, type)
  *	r)	target type
  */
 static void
-process_attribute(target)
-	int target;
+process_attribute(int target)
 {
 	int brace = 0;
 	int c;
@@ -534,9 +529,7 @@ process_attribute(target)
  *	r)	target type
  */
 static int
-function_definition(target, arg1)
-	int target;
-	char arg1[MAXTOKEN];
+function_definition(int target, char arg1[MAXTOKEN])
 {
 	int c;
 	int brace_level, isdefine;
@@ -635,9 +628,7 @@ function_definition(target, arg1)
  *	i)	target	current target
  */
 static void
-condition_macro(cc, target)
-	int cc;
-	int target;
+condition_macro(int cc, int target)
 {
 	cur = &stack[piflevel];
 	if (cc == SHARP_IFDEF || cc == SHARP_IFNDEF || cc == SHARP_IF) {
@@ -703,8 +694,7 @@ condition_macro(cc, target)
  *	r)		0: not data type, 1: data type
  */
 static int
-seems_datatype(token)
-	const char *token;
+seems_datatype(const char *token)
 {
 	int length = strlen(token);
 	const char *p = token + length;
