@@ -29,7 +29,6 @@
 #endif
 #include "cache.h"
 #include "common.h"
-#include "queue.h"
 #include "global.h"
 #include "htags.h"
 
@@ -51,9 +50,7 @@ static char command[MAXFILLEN];
  *	r)	op	file pointer
  */
 static FILE *
-open_dup_file(db, count)
-	int db;
-	int count;
+open_dup_file(int db, int count)
 {
 	char path[MAXPATHLEN];
 	FILE *op;
@@ -77,8 +74,7 @@ open_dup_file(db, count)
  *	i)	op	file pointer
  */
 static void
-close_dup_file(op)
-	FILE *op;
+close_dup_file(FILE *op)
 {
 	if (cflag) {
 		if (pclose(op) != 0)
@@ -98,6 +94,7 @@ int
 makedupindex(void)
 {
 	STRBUF *sb = strbuf_open(0);
+	STRBUF *command = strbuf_open(0);
 	int definition_count = 0;
 	char srcdir[MAXPATHLEN];
 	int db;
@@ -112,15 +109,28 @@ makedupindex(void)
 		int writing = 0;
 		int count = 0;
 		int entry_count = 0;
-		char *ctags_x, tag[IDENTLEN], prev[IDENTLEN], first_line[MAXBUFLEN], command[MAXFILLEN];
+		char *ctags_x, tag[IDENTLEN], prev[IDENTLEN], first_line[MAXBUFLEN];
 
-		if (!symbol && db == GSYMS)
+		if (gtags_exist[db] == 0)
 			continue;
 		prev[0] = 0;
 		first_line[0] = 0;
-		snprintf(command, sizeof(command), "global -xn%s%s \".*\" | gtags --sort", dynamic ? "n" : "", option);
-		if ((ip = popen(command, "r")) == NULL)
-			die("cannot execute command '%s'.", command);
+		/*
+		 * construct command line.
+		 */
+		strbuf_reset(command);
+		strbuf_sprintf(command, "%s -x%s --nofilter=path", global_path, option);
+		/*
+		 * Optimization when the --dynamic option is specified.
+		 */
+		if (dynamic) {
+			strbuf_puts(command, " --nosource");
+			if (db != GSYMS)
+				strbuf_puts(command, " --nofilter=sort");
+		}
+		strbuf_puts(command, " \".*\"");
+		if ((ip = popen(strbuf_value(command), "r")) == NULL)
+			die("cannot execute command '%s'.", strbuf_value(command));
 		while ((ctags_x = strbuf_fgets(sb, ip, STRBUF_NOCRLF)) != NULL) {
 			SPLIT ptable;
 
@@ -152,7 +162,7 @@ makedupindex(void)
 				}				
 				/* single entry */
 				if (first_line[0]) {
-					if (split(first_line, 3, &ptable) < 3) {
+					if (split(first_line, 4, &ptable) < 4) {
 						recover(&ptable);
 						die("too small number of parts.(2)\n'%s'", ctags_x);
 					}
@@ -191,7 +201,7 @@ makedupindex(void)
 		if (db == GTAGS)
 			definition_count = count;
 		if (pclose(ip) != 0)
-			die("'%s' failed.", command);
+			die("'%s' failed.", strbuf_value(command));
 		if (writing) {
 			if (!dynamic) {
 				fputs_nl(gen_list_end(), op);
@@ -209,7 +219,7 @@ makedupindex(void)
 		if (first_line[0]) {
 			SPLIT ptable;
 
-			if (split(first_line, 3, &ptable) < 3) {
+			if (split(first_line, 4, &ptable) < 4) {
 				recover(&ptable);
 				die("too small number of parts.(3)\n'%s'", ctags_x);
 			}
@@ -219,5 +229,6 @@ makedupindex(void)
 		}
 	}
 	strbuf_close(sb);
+	strbuf_close(command);
 	return definition_count;
 }
