@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
+ * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
+ *		2006
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -35,8 +36,8 @@
 #include "queue.h"
 #include "global.h"
 #include "incop.h"
-#include "path2url.h"
 #include "htags.h"
+#include "path2url.h"
 #include "common.h"
 #include "test.h"
 
@@ -75,8 +76,7 @@ static SLIST_HEAD(, file) file_q;
  * You can get file pointer any time using select_file_queue() with path.
  */
 static FILE *
-open_file_queue(path)
-	const char *path;
+open_file_queue(const char *path)
 {
 	struct file *file = (struct file *)malloc(sizeof(struct file));
 
@@ -110,8 +110,7 @@ open_file_queue(path)
  *			NULL: path not found.
  */
 static FILE *
-select_file_queue(path)
-	const char *path;
+select_file_queue(const char *path)
 {
 	struct file *file;
 
@@ -127,8 +126,7 @@ select_file_queue(path)
  *	i)	path	path name
  */
 static void
-close_file_queue(path)
-	const char *path;
+close_file_queue(const char *path)
 {
 	struct file *file;
 
@@ -215,9 +213,7 @@ settrace(void)
  *	i)	sp	stack descriptor
  */
 void
-static dump_stack(sp, label)
-	struct dirstack *sp;
-	const char *label;
+static dump_stack(struct dirstack *sp, const char *label)
 {
 	char *start = sp->start;
 	char *last = sp->last - 1;
@@ -239,8 +235,7 @@ static dump_stack(sp, label)
  *	r)		stack descriptor
  */
 static struct dirstack *
-make_stack(name)
-	const char *name;
+make_stack(const char *name)
 {
 	struct dirstack *sp = (struct dirstack *)malloc(sizeof(struct dirstack));
 	if (!sp)
@@ -269,9 +264,7 @@ make_stack(name)
  *
  */
 static void
-set_stack(sp, path)
-	struct dirstack *sp;
-	const char *path;
+set_stack(struct dirstack *sp, const char *path)
 {
 	int length = strlen(path) + 1;
 	char *p;
@@ -304,15 +297,13 @@ set_stack(sp, path)
  *	i)	s	string
  */
 static void
-push_stack(sp, s)
-	struct dirstack *sp;
-	const char *s;
+push_stack(struct dirstack *sp, const char *s)
 {
 	int length = strlen(s) + 1;
 
 	if (sp->leaved < length) {
 		fprintf(stderr, "s = %s, leaved = %d, length = %d, bufsize = %d\n",
-			s, sp->leaved, length, sp->last - sp->buf);
+			s, sp->leaved, length, (int)(sp->last - sp->buf));
 		dump_stack(sp, "abort in push_stack");
 		abort();
 	}
@@ -332,8 +323,7 @@ push_stack(sp, s)
  *	r)		string
  */
 static const char *
-top_stack(sp)
-	struct dirstack *sp;
+top_stack(struct dirstack *sp)
 {
 	char *start = sp->start;
 	char *last = sp->last;
@@ -361,9 +351,7 @@ top_stack(sp)
  *	r)		string
  */
 static const char *
-next_stack(sp, cur)
-	struct dirstack *sp;
-	const char *cur;
+next_stack(struct dirstack *sp, const char *cur)
 {
 	char *last = sp->last;
 
@@ -383,8 +371,7 @@ next_stack(sp, cur)
  *	r)		string
  */
 static const char *
-pop_stack(sp)
-	struct dirstack *sp;
+pop_stack(struct dirstack *sp)
 {
 	char *last = (char *)top_stack(sp);
 	int length = strlen(last) + 1;
@@ -405,8 +392,7 @@ pop_stack(sp)
  *	r)		string
  */
 static const char *
-shift_stack(sp)
-	struct dirstack *sp;
+shift_stack(struct dirstack *sp)
 {
 	char *start = sp->start;
 	char *last = sp->last;
@@ -433,9 +419,7 @@ shift_stack(sp)
  *	i)	from	stack descriptor
  */
 static void
-copy_stack(to, from)
-	struct dirstack *to;
-	struct dirstack *from;
+copy_stack(struct dirstack *to, struct dirstack *from)
 {
 	char *start = from->start;
 	char *last = from->last;
@@ -455,8 +439,7 @@ copy_stack(to, from)
  *	r)		path name
  */
 static const char *
-join_stack(sp)
-	struct dirstack *sp;
+join_stack(struct dirstack *sp)
 {
 	char *start = sp->start;
 	char *last = sp->last - 1;
@@ -475,39 +458,13 @@ join_stack(sp)
  *	i)	sp	stack descriptor
  */
 static void
-delete_stack(sp)
-	struct dirstack *sp;
+delete_stack(struct dirstack *sp)
 {
 	free(sp);
 }
 /*----------------------------------------------------------------------*/
 /* Main procedure							*/
 /*----------------------------------------------------------------------*/
-/*
- * Encode URL.
- *
- *	i)	url	URL
- *	r)		encoded URL
- */
-static const char *
-encode(url)
-        const char *url;
-{
-	STATIC_STRBUF(sb);
-        const char *p;
-
-	strbuf_clear(sb);
-        for (p = url; *p; p++) {
-		int c = (unsigned char)*p;
-
-                if (isalnum(c))
-			strbuf_putc(sb, c);
-		else
-			strbuf_sprintf(sb, "%%%02x", c);
-        }
-
-	return strbuf_value(sb);
-}
 /*
  * extract_lastname: extract the last name of include line.
  *
@@ -516,9 +473,7 @@ encode(url)
  *	r)		last name
  */
 static const char *
-extract_lastname(image, is_php)
-	const char *image;
-	int is_php;
+extract_lastname(const char *image, int is_php)
 {
 	static char buf[MAXBUFLEN];
 	const char *p;
@@ -604,21 +559,17 @@ extract_lastname(image, is_php)
  *	o)	files
  */
 int
-makefileindex(file, files)
-	const char *file;
-	STRBUF *files;
+makefileindex(const char *file, STRBUF *files)
 {
-	FILE *FIND, *FILEMAP, *FILES, *STDOUT, *op = NULL;
-	char *_;
+	FILE *FILEMAP, *FILES, *STDOUT, *op = NULL;
+	GFIND *gp;
+	const char *_;
 	int count = 0;
 	const char *indexlink = (Fflag) ? "../files" : "../mains";
 	STRBUF *sb = strbuf_open(0);
-	STRBUF *input = strbuf_open(0);
 	const char *target = (Fflag) ? "mains" : "_top";
 	struct dirstack *dirstack = make_stack("dirstack");
 	struct dirstack *fdstack = make_stack("fdstack");
-	const char *command = (other_files) ? "gtags --find --other | gnusort -t / -k 2"
-					: "gtags --find";
 	struct dirstack *push = make_stack("push");
 	struct dirstack *pop = make_stack("pop");
 	/*
@@ -650,8 +601,6 @@ makefileindex(file, files)
 	/*
 	 * preparations.
 	 */
-	if ((FIND = popen(command, "r")) == NULL)
-		die("cannot fork.");
 	if ((FILES = fopen(makepath(distpath, file, NULL), "w")) == NULL)
 		die("cannot open file '%s'.", file);
 
@@ -671,19 +620,13 @@ makefileindex(file, files)
 		if (!(FILEMAP = fopen(makepath(distpath, "FILEMAP", NULL), "w")))
                         die("cannot open '%s'.", makepath(distpath, "FILEMAP", NULL));
 	}
-	while ((_ = strbuf_fgets(input, FIND, STRBUF_NOCRLF)) != NULL) {
+	gp = gfind_open(dbpath, NULL, other_files);
+	while ((_ = gfind_read(gp)) != NULL) {
 		char fname[MAXPATHLEN];
-		int notsource = 0;
 
 		/* It seems like README or ChangeLog. */
-		if (*_ == ' ') {
-			if (!other_files)
-				continue;
-			_++;
-			if (test("b", _))
-				continue;
-			notsource = 1;
-		}
+		if (gp->type == GPATH_OTHER && !other_files)
+			continue;
 		_ += 2;			/* remove './' */
 		count++;
 		message(" [%d] adding %s", count, _);
@@ -726,13 +669,13 @@ makefileindex(file, files)
 				pop_stack(pop);
 			}
 			while (count_stack(push)) {
-				char cur[MAXPATHLEN], tmp[MAXPATHLEN];
+				char parent[MAXPATHLEN], cur[MAXPATHLEN], tmp[MAXPATHLEN];
 				const char *last;
 				if (count_stack(dirstack)) {
-					parent = path2fid(join_stack(dirstack));
+					strlimcpy(parent, path2fid(join_stack(dirstack)), sizeof(parent));
 					suffix = HTML;
 				} else {
-					parent = indexlink;
+					strlimcpy(parent, indexlink, sizeof(parent));
 					suffix = normal_suffix;
 				}
 				push_stack(dirstack, shift_stack(push));
@@ -811,24 +754,7 @@ makefileindex(file, files)
 		strbuf_reset(sb);
 		if (!no_order_list)
 			strbuf_puts(sb, item_begin);
-
-		{
-			char tmp[1024];
-			const char *file, *suffix = NULL, *dir = NULL;
-
-			if (notsource && dynamic) {
-				if (!(*action == '/' || count_stack(dirstack) == 0))
-					dir = "..";
-				snprintf(tmp, sizeof(tmp), "%s?pattern=%s%stype=source",
-					action, encode(_), quote_amp);
-				file = tmp;
-			} else {
-				dir = count_stack(dirstack) ? upperdir(SRCS) : SRCS;
-				file = path2fid(_);
-				suffix = HTML;
-			}
-			strbuf_puts(sb, gen_href_begin_with_title_target(dir, file, suffix, NULL, _, target));
-		}
+		strbuf_puts(sb, gen_href_begin_with_title_target(count_stack(dirstack) ? upperdir(SRCS) : SRCS, path2fid(_), HTML, NULL, _, target));
 		if (icon_list) {
 			const char *lang, *suffix, *text_icon;
 
@@ -865,10 +791,9 @@ makefileindex(file, files)
 		else
 			fputs(strbuf_value(sb), STDOUT);
 	}
+	gfind_close(gp);
 	if (map_file)
 		fclose(FILEMAP);
-	if (pclose(FIND) != 0)
-		die("cannot traverse directory.(%s)", command);
 	while (count_stack(dirstack) > 0) {
 		const char *parent, *suffix;
 
@@ -913,7 +838,6 @@ makefileindex(file, files)
 	delete_stack(pop);
 
 	strbuf_close(sb);
-	strbuf_close(input);
 	return count;
 }
 void
@@ -924,7 +848,7 @@ makeincludeindex(void)
 	char *ctags_x;
 	struct data *inc;
 	char *target = (Fflag) ? "mains" : "_top";
-	const char *command = "global -gnx \"^[ \\t]*(#[ \\t]*(import|include)|include[ \\t]*\\()\"";
+	char command[MAXFILLEN];
 
 	/*
 	 * Pick up include pattern.
@@ -932,6 +856,7 @@ makeincludeindex(void)
 	 * C: #include "xxx.h"
 	 * PHP: include("xxx.inc.php");
 	 */
+	snprintf(command, sizeof(command), "%s -gnx \"^[ \\t]*(#[ \\t]*(import|include)|include[ \\t]*\\()\"", global_path);
 	if ((PIPE = popen(command, "r")) == NULL)
 		die("cannot fork.");
 	strbuf_reset(input);
@@ -950,7 +875,7 @@ makeincludeindex(void)
 		    && strcmp(lang, "php") == 0)
 			is_php = 1;
 		last = extract_lastname(ptable.part[PART_LINE].start, is_php);
-		if (last == NULL || get_inc(last) == NULL)
+		if (last == NULL || (inc = get_inc(last)) == NULL)
 			continue;
 		recover(&ptable);
 		/*
@@ -968,7 +893,7 @@ makeincludeindex(void)
 				*q++ = *p;
 			*q = '\0';
 		}
-		put_included(last, buf);
+		put_included(inc, buf);
 	}
 	if (pclose(PIPE) != 0)
 		die("terminated abnormally.");
@@ -976,7 +901,6 @@ makeincludeindex(void)
 	for (inc = first_inc(); inc; inc = next_inc()) {
 		const char *last = inc->name;
 		int no = inc->id;
-		struct data *data;
 		FILE *INCLUDE;
 
 		if (inc->count > 1) {
@@ -1008,21 +932,20 @@ makeincludeindex(void)
 			 */
 			strbuf_reset(inc->contents);
 		}
-		data = get_included(last);
-		if (!data)
+		if (!inc->ref_count)
 			continue;
-		if (data->count == 1) {
+		if (inc->ref_count == 1) {
 			SPLIT ptable;
 			char buf[1024];
 
-			if (split(strbuf_value(data->contents), 4, &ptable) < 4) {
+			if (split(strbuf_value(inc->ref_contents), 4, &ptable) < 4) {
 				recover(&ptable);
 				die("too small number of parts in makefileindex().");
 			}
 			snprintf(buf, sizeof(buf), "%s %s", ptable.part[PART_LNO].start, ptable.part[PART_PATH].start);
 			recover(&ptable);
-			strbuf_reset(data->contents);
-			strbuf_puts(data->contents, buf);
+			strbuf_reset(inc->ref_contents);
+			strbuf_puts(inc->ref_contents, buf);
 		} else {
 			char path[MAXPATHLEN];
 
@@ -1032,8 +955,8 @@ makeincludeindex(void)
 			fputs_nl(body_begin, INCLUDE);
 			fputs_nl(gen_list_begin(), INCLUDE);
 			{
-				const char *line = strbuf_value(data->contents);
-				int count = data->count;
+				const char *line = strbuf_value(inc->ref_contents);
+				int count = inc->ref_count;
 
 				for (; count; line += strlen(line) + 1, count--)
 					fputs_nl(gen_list_body(upperdir(SRCS), line), INCLUDE);
@@ -1047,8 +970,7 @@ makeincludeindex(void)
 			 * inc->path == NULL means that information already
 			 * written to file.
 			 */
-			strbuf_reset(data->contents);
-			data->id = no;
+			strbuf_reset(inc->ref_contents);
 		}
 	}
 	strbuf_close(input);
