@@ -21,6 +21,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include <ctype.h>
 
 #include "char.h"
 #include "strbuf.h"
@@ -47,8 +48,7 @@ initialize(void)
  *	r)		1: is regex, 0: not regex
  */
 int
-isregexchar(c)
-	int c;
+isregexchar(int c)
 {
 	if (!init)
 		initialize();
@@ -61,8 +61,7 @@ isregexchar(c)
  *	r)		1: is regex, 0: not regex
  */
 int
-isregex(s)
-	const char *s;
+isregex(const char *s)
 {
 	int c;
 
@@ -79,14 +78,14 @@ isregex(s)
  *	'aaa' => \'\a\a\a\'
  */
 const char *
-quote_string(s)
-	const char *s;
+quote_string(const char *s)
 {
 	STATIC_STRBUF(sb);
 
 	strbuf_clear(sb);
 	for (; *s; s++) {
-		strbuf_putc(sb, '\\');
+		if (!isalnum((unsigned char)*s))
+			strbuf_putc(sb, '\\');
 		strbuf_putc(sb, *s);
 	}
 	return strbuf_value(sb);
