@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000
+ * Copyright (c) 1997, 1998, 1999, 2000, 2005
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -28,15 +28,35 @@
 
 #define NEXTKEY		" __.NEXTKEY"
 
-int gpath_open(const char *, int, int);
-const char *gpath_path2fid(const char *);
-const char *gpath_fid2path(const char *);
-void gpath_put(const char *);
+/*
+ * File type
+ */
+#define GPATH_SOURCE	0
+#define GPATH_OTHER	1
+
+typedef struct {
+	/* set by gfind_open() */
+	DBOP *dbop;
+	const char *prefix;
+	int other;
+	int version;
+	/* set by gfind_open() and gfind_read() */
+	int first;
+	int eod;		/* end of data */
+	/* set by gfind_read() */
+	int type;		/* File type */
+	const char *path;	/* return value of gfind_read() */
+} GFIND;
+
+int gpath_open(const char *, int);
+const char *gpath_path2fid(const char *, int *);
+const char *gpath_fid2path(const char *, int *);
+void gpath_put(const char *, int);
 void gpath_delete(const char *);
 void gpath_close(void);
 int gpath_nextkey(void);
-void gfind_open(const char *, const char *);
-const char *gfind_read(void);
-void gfind_close(void);
+GFIND *gfind_open(const char *, const char *, int);
+const char *gfind_read(GFIND *);
+void gfind_close(GFIND *);
 
 #endif /* ! _PATHOP_H_ */
