@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1997, 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2001 Tama Communications Corporation
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2005, 2006
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
 #ifndef _GTOP_H_
@@ -26,11 +26,12 @@
 
 #include "gparam.h"
 #include "dbop.h"
+#include "idset.h"
 #include "strbuf.h"
+#include "strhash.h"
 
-#define VERSIONKEY	" __.VERSION"
 #define COMPACTKEY	" __.COMPACT"
-#define PATHINDEXKEY	" __.PATHINDEX"
+#define COMPRESSKEY	" __.COMPRESS"
 
 #define GPATH		0
 #define GTAGS		1
@@ -42,10 +43,9 @@
 #define GTAGS_CREATE	1
 #define GTAGS_MODIFY	2
 
-/* gtagsopen() */
-#define GTAGS_STANDARD		0	/* standard format */
-#define GTAGS_COMPACT		1	/* compact format */
-#define GTAGS_PATHINDEX		2	/* use path index */
+/* gtags_open() */
+#define GTAGS_COMPACT		1	/* compact option */
+#define GTAGS_COMPRESS		2	/* compression option */
 /* gtags_add() */
 #define GTAGS_UNIQUE		1	/* compress duplicate lines */
 #define GTAGS_EXTRACTMETHOD	2	/* extract method from class definition */
@@ -61,7 +61,7 @@
 typedef struct {
 	DBOP *dbop;			/* descripter of DBOP */
 	int format_version;		/* format version */
-	int format;			/* GTAGS_STANDARD, GTAGS_COMPACT */
+	int format;			/* GTAGS_COMPACT, GTAGS_COMPRESS */
 	int mode;			/* mode */
 	int db;				/* 0:GTAGS, 1:GRTAGS, 2:GSYMS */
 	int openflags;			/* flags value of gtags_open() */
@@ -73,27 +73,22 @@ typedef struct {
 	int opened;			/* whether or not file opened */
 	char *line;			/* current record */
 	char tag[IDENTLEN+1];		/* current tag */
-	char prev_tag[IDENTLEN+1];	/* previous tag */
 	char path[MAXPATHLEN+1];	/* current path */
 	char prev_path[MAXPATHLEN+1];	/* previous path */
 	STRBUF *sb;			/* string buffer */
 	STRBUF *ib;			/* input buffer */
 	FILE *fp;			/* descriptor of 'path' */
-	char *lnop;			/* current line number */
+	const char *lnop;		/* current line number */
 	int lno;			/* integer value of 'lnop' */
+	STRHASH *pool;			/* record pool for compact format */
 } GTOP;
 
 const char *dbname(int);
-void makecommand(char *, char *, STRBUF *);
-void formatcheck(char *, int);
-int notnamechar(char *);
-GTOP *gtags_open(char *, char *, int, int, int);
-void gtags_put(GTOP *, char *, char *);
-char *gtags_get(GTOP *, char *);
-void gtags_add(GTOP *, char *, char *, int);
-void gtags_delete(GTOP *, char *);
-char *gtags_first(GTOP *, char *, int);
-char *gtags_next(GTOP *);
+GTOP *gtags_open(const char *, const char *, int, int);
+void gtags_put(GTOP *, const char *, const char *);
+void gtags_delete(GTOP *, IDSET *);
+const char *gtags_first(GTOP *, const char *, int);
+const char *gtags_next(GTOP *);
 void gtags_close(GTOP *);
 
 #endif /* ! _GTOP_H_ */
