@@ -15,8 +15,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,9 +43,7 @@
  *	 to this function may destroy the area.
  */
 const char *
-strmake(p, lim)
-	const char *p;
-	const char *lim;
+strmake(const char *p, const char *lim)
 {
 	STATIC_STRBUF(sb);
 	const char *c;
@@ -83,10 +81,7 @@ end:
  *	 to this function may destroy the area.
  */
 const char *
-strtrim(p, flag, len)
-	const char *p;
-	int flag;
-	int *len;
+strtrim(const char *p, int flag, int *len)
 {
 	STATIC_STRBUF(sb);
 	int cut_off = -1;
